@@ -37,86 +37,6 @@ int charsetcmp(const char* s, const char* t)
 	return ret;
 }
 
-#if VDRVERSNUM < 10503
-// cCharSetConv -------------------------------------------------------
-#include <iconv.h>
-
-class cCharSetConv {
-private:
-  iconv_t cd;
-  char *result;
-  size_t length;
-public:
-  cCharSetConv(const char *FromCode, const char *ToCode);
-  ~cCharSetConv();
-  const char *Convert(const char *From, char *To = NULL, size_t ToLength = 0);
-  static const char *SystemCharacterTable(void) { return I18nCharSets()[Setup.OSDLanguage]; }
-};
-
-cCharSetConv::cCharSetConv(const char *FromCode, const char *ToCode)
-{
-  if (!FromCode)
-     FromCode = "UTF-8";
-  if (!ToCode)
-     ToCode = "UTF-8";
-  cd = (FromCode && ToCode) ? iconv_open(ToCode, FromCode) : (iconv_t)-1;
-  result = NULL;
-  length = 0;
-}
-
-cCharSetConv::~cCharSetConv()
-{
-  free(result);
-  iconv_close(cd);
-}
-
-const char *cCharSetConv::Convert(const char *From, char *To, size_t ToLength)
-{
-  if (cd != (iconv_t)-1 && From && *From) {
-     char *FromPtr = (char *)From;
-     size_t FromLength = strlen(From);
-     char *ToPtr = To;
-     if (!ToPtr) {
-        length = max(length, FromLength * 2); // some reserve to avoid later reallocations
-        result = (char *)realloc(result, length);
-        ToPtr = result;
-        ToLength = length;
-        }
-     else if (!ToLength)
-        return From; // can't convert into a zero sized buffer
-     ToLength--; // save space for terminating 0
-     char *Converted = ToPtr;
-     while (FromLength > 0) {
-           if (iconv(cd, &FromPtr, &FromLength, &ToPtr, &ToLength) == size_t(-1)) {
-              if (errno == E2BIG || errno == EILSEQ && ToLength < 1) {
-                 if (To)
-                    break; // caller provided a fixed size buffer, but it was too small
-                 // The result buffer is too small, so increase it:
-                 size_t d = ToPtr - result;
-                 size_t r = length / 2;
-                 length += r;
-                 Converted = result = (char *)realloc(result, length);
-                 ToLength += r;
-                 ToPtr = result + d;
-                 }
-              if (errno == EILSEQ) {
-                 // A character can't be converted, so mark it with '?' and proceed:
-                 FromPtr++;
-                 FromLength--;
-                 *ToPtr++ = '?';
-                 ToLength--;
-                 }
-              else if (errno != E2BIG)
-                 return From; // unknown error, return original string
-              }
-           }
-     *ToPtr = 0;
-     return Converted;
-     }
-  return From;
-}
-#endif
-
 // cSvdrpConnection -------------------------------------------------------
 
 int cSvdrpConnection::Connect() {
