@@ -9,15 +9,15 @@
 #include <vdr/plugin.h>
 #include <vdr/thread.h>
 #include <vdr/tools.h>
+#include <vdr/i18n.h>
 
 #include "svdrpservice.h"
 #include "connection.h"
 #include "setup.h"
-#include "i18n.h"
 
 #define MAX_SVDRP_CONNECTIONS 8
 
-static const char *VERSION        = "0.0.4";
+static const char *VERSION        = "1.0.0";
 static const char *DESCRIPTION    = "SVDRP client";
 
 class cPluginSvdrpService : public cPlugin {
@@ -61,8 +61,8 @@ cPluginSvdrpService::~cPluginSvdrpService()
 
 const char *cPluginSvdrpService::CommandLineHelp(void)
 {
-	return "  IP[:PORT]  Default server IP and optional port (e.g. 192.168.0.1:2001).\n"
-	       "             If no port is given, the default SVDRP port 2001 is asumed.\n";
+	return "  IP[:PORT]  Default server IP and optional port (e.g. 192.0.2.1:6419).\n"
+	       "             If no port is given, the default SVDRP port 6419 is asumed.\n";
 }
 
 bool cPluginSvdrpService::ProcessArgs(int argc, char *argv[])
@@ -92,9 +92,6 @@ bool cPluginSvdrpService::Initialize(void)
 
 bool cPluginSvdrpService::Start(void)
 {
-#if VDRVERSNUM < 10507
-  RegisterI18n(Phrases);
-#endif
   return true;
 }
 
